@@ -4,315 +4,360 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="../src/mainwindow.ui" line="14"/>
+        <location filename="../src/ui_mainwindow.h" line="569"/>
         <source>Program_Name</source>
         <translation>Programma_Naam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="46"/>
+        <location filename="../src/mainwindow.ui" line="46"/>
+        <location filename="../src/ui_mainwindow.h" line="571"/>
         <source>Quit application</source>
         <translation>Verlaat de applicatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="49"/>
+        <location filename="../src/mainwindow.ui" line="49"/>
+        <location filename="../src/ui_mainwindow.h" line="573"/>
         <source>Close</source>
         <translation>Sluiten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="55"/>
+        <location filename="../src/mainwindow.ui" line="55"/>
+        <location filename="../src/ui_mainwindow.h" line="575"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="87"/>
+        <location filename="../src/mainwindow.ui" line="87"/>
+        <location filename="../src/ui_mainwindow.h" line="578"/>
         <source>Display help </source>
         <translation>Toon help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="90"/>
+        <location filename="../src/mainwindow.ui" line="90"/>
+        <location filename="../src/ui_mainwindow.h" line="580"/>
         <source>Help</source>
         <translation>Hulp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="96"/>
+        <location filename="../src/mainwindow.ui" line="96"/>
+        <location filename="../src/ui_mainwindow.h" line="582"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="112"/>
+        <location filename="../src/mainwindow.ui" line="112"/>
+        <location filename="../src/ui_mainwindow.h" line="584"/>
         <source>Back</source>
         <translation>Terug</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="169"/>
+        <location filename="../src/mainwindow.ui" line="169"/>
+        <location filename="../src/ui_mainwindow.h" line="586"/>
         <source>Next</source>
         <translation>Volgende</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="194"/>
+        <location filename="../src/mainwindow.ui" line="194"/>
+        <location filename="../src/ui_mainwindow.h" line="591"/>
         <source>About this application</source>
         <translation>Over deze toepassing</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="197"/>
+        <location filename="../src/mainwindow.ui" line="197"/>
+        <location filename="../src/ui_mainwindow.h" line="593"/>
         <source>About...</source>
         <translation>Over...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="203"/>
+        <location filename="../src/mainwindow.ui" line="203"/>
+        <location filename="../src/ui_mainwindow.h" line="595"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="219"/>
+        <location filename="../src/mainwindow.ui" line="219"/>
+        <location filename="../src/ui_mainwindow.h" line="597"/>
         <source>View Log</source>
         <translation>Logboek bekijken</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="253"/>
-        <location filename="../mainwindow.cpp" line="616"/>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="../src/mainwindow.ui" line="253"/>
+        <location filename="../src/mainwindow.cpp" line="583"/>
+        <location filename="../src/mainwindow.cpp" line="606"/>
+        <location filename="../src/ui_mainwindow.h" line="598"/>
         <source>Select ISO</source>
         <translation>Selecteer ISO</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="263"/>
+        <location filename="../src/mainwindow.ui" line="263"/>
+        <location filename="../src/ui_mainwindow.h" line="599"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecteer Doel USB Apparaat&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="273"/>
+        <location filename="../src/mainwindow.ui" line="273"/>
+        <location filename="../src/ui_mainwindow.h" line="600"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecteer ISO bestand&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="289"/>
+        <location filename="../src/mainwindow.ui" line="289"/>
+        <location filename="../src/ui_mainwindow.h" line="601"/>
         <source>Advanced Options</source>
         <translation>Geavanceerde Opties</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="307"/>
+        <location filename="../src/mainwindow.ui" line="307"/>
+        <location filename="../src/ui_mainwindow.h" line="602"/>
         <source>Make the ext4 filesystem even if one exists</source>
         <translation>Creëer het ext4 bestandssysteem zelfs als er al een is</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="314"/>
+        <location filename="../src/mainwindow.ui" line="314"/>
+        <location filename="../src/ui_mainwindow.h" line="603"/>
         <source>Save the original boot directory when updating a live-usb</source>
         <translation>Sla de orginele boot map op wanneer een live-usb ge-update wordt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="321"/>
+        <location filename="../src/mainwindow.ui" line="321"/>
+        <location filename="../src/ui_mainwindow.h" line="605"/>
         <source>Use gpt partitioning instead of msdos</source>
         <translation>Gebruik gpt partitionering in plaats van msdos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="324"/>
+        <location filename="../src/mainwindow.ui" line="324"/>
+        <location filename="../src/ui_mainwindow.h" line="607"/>
         <source>GPT partitioning</source>
         <translation>GPT partitionering</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="331"/>
+        <location filename="../src/mainwindow.ui" line="331"/>
+        <location filename="../src/ui_mainwindow.h" line="608"/>
         <source>Update (only update an existing live-usb)</source>
         <translation>Updaten (alleen updaten op een bestaande live-usb)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="338"/>
+        <location filename="../src/mainwindow.ui" line="338"/>
+        <location filename="../src/ui_mainwindow.h" line="610"/>
         <source>Don&apos;t replace syslinux files</source>
         <translation>Syslinux bestanden niet vervangen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="341"/>
+        <location filename="../src/mainwindow.ui" line="341"/>
+        <location filename="../src/ui_mainwindow.h" line="612"/>
         <source>Keep syslinux files</source>
         <translation>Syslinux bestanden behouden</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="348"/>
+        <location filename="../src/mainwindow.ui" line="348"/>
+        <location filename="../src/ui_mainwindow.h" line="613"/>
         <source>Ignore USB/removable check</source>
         <translation>Negeer USB/verwijderbaar controle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="355"/>
+        <location filename="../src/mainwindow.ui" line="355"/>
+        <location filename="../src/ui_mainwindow.h" line="614"/>
         <source>Temporarily disable automounting</source>
         <translation>Tijdelijk automatisch aankoppelen uitschakelen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="365"/>
+        <location filename="../src/mainwindow.ui" line="365"/>
+        <location filename="../src/ui_mainwindow.h" line="618"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
         <translation>pmbr_boot schijf vlag instellen (zal niet opstarten via UEFI)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="372"/>
+        <location filename="../src/mainwindow.ui" line="372"/>
+        <location filename="../src/ui_mainwindow.h" line="619"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
         <translation>Gebruik fuseiso niet om iso bestanden aan te koppelen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="398"/>
+        <location filename="../src/mainwindow.ui" line="398"/>
+        <location filename="../src/ui_mainwindow.h" line="620"/>
         <source>Size of ESP (uefi) partition:</source>
         <translation>Formaat van ESP (uefi) partitie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="421"/>
+        <location filename="../src/mainwindow.ui" line="421"/>
+        <location filename="../src/ui_mainwindow.h" line="621"/>
         <source>Verbosity (less to more):</source>
         <translation>Verbosity (less naar more):</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="465"/>
+        <location filename="../src/mainwindow.ui" line="465"/>
+        <location filename="../src/ui_mainwindow.h" line="623"/>
         <source>vfat</source>
         <translation>vfat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="506"/>
+        <location filename="../src/mainwindow.ui" line="506"/>
+        <location filename="../src/ui_mainwindow.h" line="628"/>
         <source>Data partition format type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="460"/>
+        <location filename="../src/mainwindow.ui" line="460"/>
+        <location filename="../src/ui_mainwindow.h" line="622"/>
         <source>exfat</source>
         <translation>exfat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="470"/>
+        <location filename="../src/mainwindow.ui" line="470"/>
+        <location filename="../src/ui_mainwindow.h" line="624"/>
         <source>ext4</source>
         <translation>ext4</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="475"/>
+        <location filename="../src/mainwindow.ui" line="475"/>
+        <location filename="../src/ui_mainwindow.h" line="625"/>
         <source>ntfs</source>
         <translation>ntfs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="499"/>
+        <location filename="../src/mainwindow.ui" line="499"/>
+        <location filename="../src/ui_mainwindow.h" line="627"/>
         <source>Make separate data partition (percent)</source>
         <translation>Maak afzonderlijke data partitie (procent)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="516"/>
+        <location filename="../src/mainwindow.ui" line="516"/>
+        <location filename="../src/ui_mainwindow.h" line="629"/>
         <source>Refresh drive list</source>
         <translation>Refresh schijf list</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="529"/>
-        <location filename="../mainwindow.cpp" line="585"/>
+        <location filename="../src/mainwindow.ui" line="529"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
+        <location filename="../src/ui_mainwindow.h" line="630"/>
         <source>Show advanced options</source>
         <translation>Laat geavanceerde opties zien</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="548"/>
+        <location filename="../src/mainwindow.ui" line="548"/>
+        <location filename="../src/ui_mainwindow.h" line="631"/>
         <source>Mode</source>
         <translation>Modus</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="563"/>
+        <location filename="../src/mainwindow.ui" line="563"/>
+        <location filename="../src/ui_mainwindow.h" line="632"/>
         <source>Full-featured mode - writable Li&amp;veUSB</source>
         <translation>Full-featured modus - beschrijfbare Li&amp;veUSB</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="573"/>
+        <location filename="../src/mainwindow.ui" line="573"/>
+        <location filename="../src/ui_mainwindow.h" line="634"/>
         <source>Read-only, cannot be used with persistency</source>
         <translation>Enkel-lezen, kan niet gebruikt worden met persistentie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="576"/>
+        <location filename="../src/mainwindow.ui" line="576"/>
+        <location filename="../src/ui_mainwindow.h" line="636"/>
         <source>Image &amp;mode - read-only LiveUSB (dd)</source>
         <translation>Beeld &amp;modus - alleen-lezen LiveUSB (dd)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="589"/>
+        <location filename="../src/mainwindow.ui" line="589"/>
+        <location filename="../src/ui_mainwindow.h" line="637"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
         <translation>Voor distrubuties anders dan antiX/MX gebruik beeld modus (dd)&quot;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="637"/>
+        <location filename="../src/mainwindow.ui" line="637"/>
+        <location filename="../src/ui_mainwindow.h" line="638"/>
         <source>Options</source>
         <translation>Opties</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="675"/>
+        <location filename="../src/mainwindow.ui" line="675"/>
+        <location filename="../src/ui_mainwindow.h" line="639"/>
         <source>Percent of USB-device to use:</source>
         <translation>Percentage van USB-apparaat om te gebruiken:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="682"/>
+        <location filename="../src/mainwindow.ui" line="682"/>
+        <location filename="../src/ui_mainwindow.h" line="640"/>
         <source>Label ext partition:</source>
         <translation>Label ext partitie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="730"/>
+        <location filename="../src/mainwindow.ui" line="730"/>
+        <location filename="../src/ui_mainwindow.h" line="642"/>
         <source>Don&apos;t run commands that affect the usb device</source>
         <translation>Geen commando&apos;s uitvoeren die het usb apparaat beïnvloeden</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="733"/>
+        <location filename="../src/mainwindow.ui" line="733"/>
+        <location filename="../src/ui_mainwindow.h" line="644"/>
         <source>Dry run (no change to system)</source>
         <translation>Test uitvoering (geen veranderingen aan het systeem)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="740"/>
+        <location filename="../src/mainwindow.ui" line="740"/>
+        <location filename="../src/ui_mainwindow.h" line="646"/>
         <source>clone from a mounted live-usb or iso-file.</source>
         <translation>kloon van een aangekoppelde live-usb of iso-bestand.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="743"/>
+        <location filename="../src/mainwindow.ui" line="743"/>
+        <location filename="../src/ui_mainwindow.h" line="648"/>
         <source>Clone a mounted live system</source>
         <translation>Een aangekoppeld live systeem klonen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="750"/>
+        <location filename="../src/mainwindow.ui" line="750"/>
+        <location filename="../src/ui_mainwindow.h" line="650"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
         <translation>Stel in om op te starten van een versleutelde partitie, zal bij de eerste opstart naar de wachtwoordzin vragen </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="753"/>
+        <location filename="../src/mainwindow.ui" line="753"/>
+        <location filename="../src/ui_mainwindow.h" line="652"/>
         <source>Encrypt</source>
         <translation>Versleutelen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="760"/>
+        <location filename="../src/mainwindow.ui" line="760"/>
+        <location filename="../src/ui_mainwindow.h" line="653"/>
         <source>Clone running live system</source>
         <translation>Kloon lopend live systeem</translation>
     </message>
     <message>
-        <source>Confirmation</source>
-        <translation type="vanished">Bevestiging</translation>
-    </message>
-    <message>
-        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
-        <translation type="vanished">Doelapparaat is %1 groter dan %2 GB. Wilt u doorgaan?</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="439"/>
-        <location filename="../mainwindow.cpp" line="570"/>
-        <location filename="../mainwindow.cpp" line="738"/>
+        <location filename="../src/mainwindow.cpp" line="398"/>
+        <location filename="../src/mainwindow.cpp" line="537"/>
+        <location filename="../src/mainwindow.cpp" line="705"/>
         <source>Failure</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../src/mainwindow.cpp" line="155"/>
         <source>Source and destination are on the same device, please select again.</source>
         <translation>Bron en bestemming bevinden zich op hetzelfde apparaat, selecteer aub opnieuw.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../src/mainwindow.cpp" line="750"/>
         <source>Source Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../src/mainwindow.cpp" line="751"/>
         <source>Could not find the source linuxfs file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="142"/>
+        <location filename="../src/mainwindow.cpp" line="772"/>
         <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="145"/>
+        <location filename="../src/mainwindow.cpp" line="775"/>
         <source>Size Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="151"/>
+        <location filename="../src/mainwindow.cpp" line="783"/>
         <source>The target device %1 is larger than %2 GB.
 
 This may indicate you have selected the wrong device.
@@ -320,12 +365,12 @@ Are you sure you want to proceed?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="158"/>
+        <location filename="../src/mainwindow.cpp" line="790"/>
         <source>Large Target Device Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="248"/>
+        <location filename="../src/mainwindow.cpp" line="194"/>
         <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
 
 Please wait until the process is completed</source>
@@ -334,37 +379,37 @@ Please wait until the process is completed</source>
 Wacht aub tot het proces is voltooid</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="260"/>
+        <location filename="../src/mainwindow.cpp" line="205"/>
         <source>MX Live Usb Maker</source>
         <translation>MX Live Usb Maker</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
         <source>Success</source>
         <translation>Gelukt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
         <source>LiveUSB creation successful!</source>
         <translation>LiveUSB creatie geslaagd!</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="439"/>
+        <location filename="../src/mainwindow.cpp" line="398"/>
         <source>Error encountered in the LiveUSB creation process</source>
         <translation>Fout tegengekomen in het LiveUSB creatieproces</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="497"/>
+        <location filename="../src/mainwindow.cpp" line="464"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="497"/>
+        <location filename="../src/mainwindow.cpp" line="464"/>
         <source>Please select a USB device to write to</source>
         <translation>Selecteer a.u.b. een USB apparaat om naar te schrijven</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="500"/>
+        <location filename="../src/mainwindow.cpp" line="467"/>
         <source>These actions will destroy all data on 
 
 </source>
@@ -373,85 +418,85 @@ Wacht aub tot het proces is voltooid</translation>
 </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="501"/>
+        <location filename="../src/mainwindow.cpp" line="468"/>
         <source>Do you wish to continue?</source>
         <translation>Wilt u doorgaan?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="533"/>
+        <location filename="../src/mainwindow.cpp" line="500"/>
         <source>About %1</source>
         <translation>Over %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="534"/>
+        <location filename="../src/mainwindow.cpp" line="501"/>
         <source>Version: </source>
         <translation>Versie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../src/mainwindow.cpp" line="503"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Programma voor het creëeren van een live-usb van een iso-bestand, een andere live-usb, een live-cd/dvd, of een lopend live systeem.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="539"/>
+        <location filename="../src/mainwindow.cpp" line="506"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="540"/>
+        <location filename="../src/mainwindow.cpp" line="507"/>
         <source>%1 License</source>
         <translation>%1 Licentie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="547"/>
+        <location filename="../src/mainwindow.cpp" line="514"/>
         <source>%1 Help</source>
         <translation>%1 Help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="555"/>
+        <location filename="../src/mainwindow.cpp" line="522"/>
         <source>Select an ISO file to write to the USB drive</source>
         <translation>Selecteer een ISO bestand om naar de USB schijf te schrijven</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="556"/>
+        <location filename="../src/mainwindow.cpp" line="523"/>
         <source>ISO Files (*.iso);;All Files (*.*)</source>
         <translation>ISO Bestanden (*.iso);;Alle Bestanden (*.*)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="561"/>
-        <location filename="../mainwindow.cpp" line="611"/>
+        <location filename="../src/mainwindow.cpp" line="528"/>
+        <location filename="../src/mainwindow.cpp" line="578"/>
         <source>Select Source Directory</source>
         <translation>Selecteer Bron Map</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="570"/>
+        <location filename="../src/mainwindow.cpp" line="537"/>
         <source>Could not find linuxfs file</source>
         <translation>Kon linuxfs-bestand niet vinden</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="585"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
         <source>Hide advanced options</source>
         <translation>Verberg geavanceerde opties</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="610"/>
-        <location filename="../mainwindow.cpp" line="629"/>
+        <location filename="../src/mainwindow.cpp" line="577"/>
+        <location filename="../src/mainwindow.cpp" line="596"/>
         <source>Select Source</source>
         <translation>Selecteer Bron</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="615"/>
-        <location filename="../mainwindow.cpp" line="637"/>
+        <location filename="../src/mainwindow.cpp" line="582"/>
+        <location filename="../src/mainwindow.cpp" line="604"/>
         <source>Select ISO file</source>
         <translation>Selecteer ISO bestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="631"/>
+        <location filename="../src/mainwindow.cpp" line="598"/>
         <source>clone</source>
         <translation>klonen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="698"/>
+        <location filename="../src/mainwindow.cpp" line="665"/>
         <source>Could not find a log file at: </source>
         <translation>Kon geen logbestand vinden op:</translation>
     </message>
@@ -459,64 +504,64 @@ Wacht aub tot het proces is voltooid</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="74"/>
+        <location filename="../src/about.cpp" line="74"/>
         <source>License</source>
         <translation>Licentie</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="75"/>
-        <location filename="../about.cpp" line="85"/>
+        <location filename="../src/about.cpp" line="75"/>
+        <location filename="../src/about.cpp" line="85"/>
         <source>Changelog</source>
         <translation>Changelog</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="76"/>
+        <location filename="../src/about.cpp" line="76"/>
         <source>Cancel</source>
         <translation>Ongedaan maken</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="99"/>
+        <location filename="../src/about.cpp" line="99"/>
         <source>&amp;Close</source>
         <translation>&amp;Sluiten</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../src/main.cpp" line="60"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Programma voor het creëeren van een live-usb van een iso-bestand, een andere live-usb, een live-cd/dvd, of een lopend live systeem.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../src/main.cpp" line="64"/>
         <source>filename</source>
         <translation>bestandsnaam</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../src/main.cpp" line="64"/>
         <source>Name of .iso file to open</source>
         <translation>Naam van .iso bestand om te openen</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../src/main.cpp" line="65"/>
         <source>[filename]</source>
         <translation>[filename]</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../src/main.cpp" line="93"/>
+        <location filename="../src/main.cpp" line="102"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../src/main.cpp" line="94"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../src/main.cpp" line="102"/>
         <source>You must run this program as root.</source>
         <translation>U dient deze toepassing als &apos;root&apos; uit te voeren.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="111"/>
+        <location filename="../src/main.cpp" line="117"/>
         <source>version:</source>
         <translation>versie:</translation>
     </message>
