@@ -4,328 +4,376 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="../src/mainwindow.ui" line="14"/>
+        <location filename="../src/ui_mainwindow.h" line="569"/>
         <source>Program_Name</source>
         <translation>Название программы</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="46"/>
+        <location filename="../src/mainwindow.ui" line="46"/>
+        <location filename="../src/ui_mainwindow.h" line="571"/>
         <source>Quit application</source>
         <translation>Выйти из приложения</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="49"/>
+        <location filename="../src/mainwindow.ui" line="49"/>
+        <location filename="../src/ui_mainwindow.h" line="573"/>
         <source>Close</source>
         <translation>Закрыть</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="55"/>
+        <location filename="../src/mainwindow.ui" line="55"/>
+        <location filename="../src/ui_mainwindow.h" line="575"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="87"/>
+        <location filename="../src/mainwindow.ui" line="87"/>
+        <location filename="../src/ui_mainwindow.h" line="578"/>
         <source>Display help </source>
         <translation>Показать справку</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="90"/>
+        <location filename="../src/mainwindow.ui" line="90"/>
+        <location filename="../src/ui_mainwindow.h" line="580"/>
         <source>Help</source>
         <translation>Помощь</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="96"/>
+        <location filename="../src/mainwindow.ui" line="96"/>
+        <location filename="../src/ui_mainwindow.h" line="582"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="112"/>
+        <location filename="../src/mainwindow.ui" line="112"/>
+        <location filename="../src/ui_mainwindow.h" line="584"/>
         <source>Back</source>
         <translation>Назад</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="169"/>
+        <location filename="../src/mainwindow.ui" line="169"/>
+        <location filename="../src/ui_mainwindow.h" line="586"/>
         <source>Next</source>
         <translation>Следующий</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="194"/>
+        <location filename="../src/mainwindow.ui" line="194"/>
+        <location filename="../src/ui_mainwindow.h" line="591"/>
         <source>About this application</source>
         <translation>Об этом приложении</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="197"/>
+        <location filename="../src/mainwindow.ui" line="197"/>
+        <location filename="../src/ui_mainwindow.h" line="593"/>
         <source>About...</source>
         <translation>О программе...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="203"/>
+        <location filename="../src/mainwindow.ui" line="203"/>
+        <location filename="../src/ui_mainwindow.h" line="595"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="219"/>
+        <location filename="../src/mainwindow.ui" line="219"/>
+        <location filename="../src/ui_mainwindow.h" line="597"/>
         <source>View Log</source>
         <translation>Просмотр журнала</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="253"/>
-        <location filename="../mainwindow.cpp" line="616"/>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="../src/mainwindow.ui" line="253"/>
+        <location filename="../src/mainwindow.cpp" line="583"/>
+        <location filename="../src/mainwindow.cpp" line="606"/>
+        <location filename="../src/ui_mainwindow.h" line="598"/>
         <source>Select ISO</source>
         <translation>Выбор ISO</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="263"/>
+        <location filename="../src/mainwindow.ui" line="263"/>
+        <location filename="../src/ui_mainwindow.h" line="599"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Выбор целевого USB накопителя&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="273"/>
+        <location filename="../src/mainwindow.ui" line="273"/>
+        <location filename="../src/ui_mainwindow.h" line="600"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Выбор файла ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="289"/>
+        <location filename="../src/mainwindow.ui" line="289"/>
+        <location filename="../src/ui_mainwindow.h" line="601"/>
         <source>Advanced Options</source>
         <translation>Расширенные опции</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="307"/>
+        <location filename="../src/mainwindow.ui" line="307"/>
+        <location filename="../src/ui_mainwindow.h" line="602"/>
         <source>Make the ext4 filesystem even if one exists</source>
         <translation>Создайте файловую систему ext4, даже если она уже существует.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="314"/>
+        <location filename="../src/mainwindow.ui" line="314"/>
+        <location filename="../src/ui_mainwindow.h" line="603"/>
         <source>Save the original boot directory when updating a live-usb</source>
         <translation>Сохраните исходный каталог загрузки при обновлении живого USB.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="321"/>
+        <location filename="../src/mainwindow.ui" line="321"/>
+        <location filename="../src/ui_mainwindow.h" line="605"/>
         <source>Use gpt partitioning instead of msdos</source>
         <translation>Использовать gpt разделы вместо msdos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="324"/>
+        <location filename="../src/mainwindow.ui" line="324"/>
+        <location filename="../src/ui_mainwindow.h" line="607"/>
         <source>GPT partitioning</source>
         <translation>Партиционирование GPT</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="331"/>
+        <location filename="../src/mainwindow.ui" line="331"/>
+        <location filename="../src/ui_mainwindow.h" line="608"/>
         <source>Update (only update an existing live-usb)</source>
         <translation>Обновление (только существующий live-usb)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="338"/>
+        <location filename="../src/mainwindow.ui" line="338"/>
+        <location filename="../src/ui_mainwindow.h" line="610"/>
         <source>Don&apos;t replace syslinux files</source>
         <translation>Не заменяйте файлы syslinux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="341"/>
+        <location filename="../src/mainwindow.ui" line="341"/>
+        <location filename="../src/ui_mainwindow.h" line="612"/>
         <source>Keep syslinux files</source>
         <translation>Сохраните файлы syslinux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="348"/>
+        <location filename="../src/mainwindow.ui" line="348"/>
+        <location filename="../src/ui_mainwindow.h" line="613"/>
         <source>Ignore USB/removable check</source>
         <translation>Игнорировать проверку USB/съемного носителя</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="355"/>
+        <location filename="../src/mainwindow.ui" line="355"/>
+        <location filename="../src/ui_mainwindow.h" line="614"/>
         <source>Temporarily disable automounting</source>
         <translation>Временно отключите автомонтирование</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="365"/>
+        <location filename="../src/mainwindow.ui" line="365"/>
+        <location filename="../src/ui_mainwindow.h" line="618"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
         <translation>Установить флаг накопителя pmbr_boot (не будет загружаться через UEFI)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="372"/>
+        <location filename="../src/mainwindow.ui" line="372"/>
+        <location filename="../src/ui_mainwindow.h" line="619"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
         <translation>Не использовать fuseiso для монтирования файлов iso</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="398"/>
+        <location filename="../src/mainwindow.ui" line="398"/>
+        <location filename="../src/ui_mainwindow.h" line="620"/>
         <source>Size of ESP (uefi) partition:</source>
         <translation>Размер раздела ESP (uefi):</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="421"/>
+        <location filename="../src/mainwindow.ui" line="421"/>
+        <location filename="../src/ui_mainwindow.h" line="621"/>
         <source>Verbosity (less to more):</source>
         <translation>Степень детализации (от меньшего к большему):</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="465"/>
+        <location filename="../src/mainwindow.ui" line="465"/>
+        <location filename="../src/ui_mainwindow.h" line="623"/>
         <source>vfat</source>
         <translation>vfat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="506"/>
+        <location filename="../src/mainwindow.ui" line="506"/>
+        <location filename="../src/ui_mainwindow.h" line="628"/>
         <source>Data partition format type</source>
         <translation>Тип формата раздела данных</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="460"/>
+        <location filename="../src/mainwindow.ui" line="460"/>
+        <location filename="../src/ui_mainwindow.h" line="622"/>
         <source>exfat</source>
         <translation>exfat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="470"/>
+        <location filename="../src/mainwindow.ui" line="470"/>
+        <location filename="../src/ui_mainwindow.h" line="624"/>
         <source>ext4</source>
         <translation>ext4</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="475"/>
+        <location filename="../src/mainwindow.ui" line="475"/>
+        <location filename="../src/ui_mainwindow.h" line="625"/>
         <source>ntfs</source>
         <translation>ntfs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="499"/>
+        <location filename="../src/mainwindow.ui" line="499"/>
+        <location filename="../src/ui_mainwindow.h" line="627"/>
         <source>Make separate data partition (percent)</source>
         <translation>Создать отдельный раздел данных (проценты)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="516"/>
+        <location filename="../src/mainwindow.ui" line="516"/>
+        <location filename="../src/ui_mainwindow.h" line="629"/>
         <source>Refresh drive list</source>
         <translation>Обновить список накопителей</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="529"/>
-        <location filename="../mainwindow.cpp" line="585"/>
+        <location filename="../src/mainwindow.ui" line="529"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
+        <location filename="../src/ui_mainwindow.h" line="630"/>
         <source>Show advanced options</source>
         <translation>Показать расширенные опции</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="548"/>
+        <location filename="../src/mainwindow.ui" line="548"/>
+        <location filename="../src/ui_mainwindow.h" line="631"/>
         <source>Mode</source>
         <translation>Режим</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="563"/>
+        <location filename="../src/mainwindow.ui" line="563"/>
+        <location filename="../src/ui_mainwindow.h" line="632"/>
         <source>Full-featured mode - writable Li&amp;veUSB</source>
         <translation>Полнофункциональный режим - записывае&amp;мый LiveUSB</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="573"/>
+        <location filename="../src/mainwindow.ui" line="573"/>
+        <location filename="../src/ui_mainwindow.h" line="634"/>
         <source>Read-only, cannot be used with persistency</source>
         <translation>Режим только на чтение, невозможно запомнить сеанс</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="576"/>
+        <location filename="../src/mainwindow.ui" line="576"/>
+        <location filename="../src/ui_mainwindow.h" line="636"/>
         <source>Image &amp;mode - read-only LiveUSB (dd)</source>
         <translation>Режим образа - LiveUSB (dd) тол&amp;ько для чтения</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="589"/>
+        <location filename="../src/mainwindow.ui" line="589"/>
+        <location filename="../src/ui_mainwindow.h" line="637"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
         <translation>Для дистрибутивов отличных от antiX/MX используйте Режим образа (dd).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="637"/>
+        <location filename="../src/mainwindow.ui" line="637"/>
+        <location filename="../src/ui_mainwindow.h" line="638"/>
         <source>Options</source>
         <translation>Варианты</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="675"/>
+        <location filename="../src/mainwindow.ui" line="675"/>
+        <location filename="../src/ui_mainwindow.h" line="639"/>
         <source>Percent of USB-device to use:</source>
         <translation>Процент использования USB-накопителя:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="682"/>
+        <location filename="../src/mainwindow.ui" line="682"/>
+        <location filename="../src/ui_mainwindow.h" line="640"/>
         <source>Label ext partition:</source>
         <translation>Метка раздела ext:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="730"/>
+        <location filename="../src/mainwindow.ui" line="730"/>
+        <location filename="../src/ui_mainwindow.h" line="642"/>
         <source>Don&apos;t run commands that affect the usb device</source>
         <translation>Не выполнять команды, влияющие на usb накопитель</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="733"/>
+        <location filename="../src/mainwindow.ui" line="733"/>
+        <location filename="../src/ui_mainwindow.h" line="644"/>
         <source>Dry run (no change to system)</source>
         <translation>Пробный прогон (без изменений системы)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="740"/>
+        <location filename="../src/mainwindow.ui" line="740"/>
+        <location filename="../src/ui_mainwindow.h" line="646"/>
         <source>clone from a mounted live-usb or iso-file.</source>
         <translation>Клонировать с подмонтированного live-usb или iso-файла</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="743"/>
+        <location filename="../src/mainwindow.ui" line="743"/>
+        <location filename="../src/ui_mainwindow.h" line="648"/>
         <source>Clone a mounted live system</source>
         <translation>Клонировать смонтированную live систему</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="750"/>
+        <location filename="../src/mainwindow.ui" line="750"/>
+        <location filename="../src/ui_mainwindow.h" line="650"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
         <translation>Настроить загрузку с зашифрованного раздела, запросит пароль при первой загрузке</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="753"/>
+        <location filename="../src/mainwindow.ui" line="753"/>
+        <location filename="../src/ui_mainwindow.h" line="652"/>
         <source>Encrypt</source>
         <translation>Зашифровать</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="760"/>
+        <location filename="../src/mainwindow.ui" line="760"/>
+        <location filename="../src/ui_mainwindow.h" line="653"/>
         <source>Clone running live system</source>
         <translation>Клонировать работающую live систему</translation>
     </message>
     <message>
-        <source>Confirmation</source>
-        <translation type="vanished">Подтверждение</translation>
-    </message>
-    <message>
-        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
-        <translation type="vanished">Целевое устройство %1 превышает %2 GB. Вы хотите продолжить?</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="439"/>
-        <location filename="../mainwindow.cpp" line="570"/>
-        <location filename="../mainwindow.cpp" line="738"/>
+        <location filename="../src/mainwindow.cpp" line="398"/>
+        <location filename="../src/mainwindow.cpp" line="537"/>
+        <location filename="../src/mainwindow.cpp" line="705"/>
         <source>Failure</source>
         <translation>Сбой</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../src/mainwindow.cpp" line="155"/>
         <source>Source and destination are on the same device, please select again.</source>
         <translation>Источник и место назначения на одном устройстве, выберите еще раз.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../src/mainwindow.cpp" line="750"/>
         <source>Source Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка исходника</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../src/mainwindow.cpp" line="751"/>
         <source>Could not find the source linuxfs file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось найти исходный файл linuxfs.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="142"/>
+        <location filename="../src/mainwindow.cpp" line="772"/>
         <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
-        <translation type="unfinished"></translation>
+        <translation>Предупреждение: Целевое устройство (%1) меньше исходного (%2). Данные могут не поместиться. Хотите продолжить?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="145"/>
+        <location filename="../src/mainwindow.cpp" line="775"/>
         <source>Size Warning</source>
-        <translation type="unfinished"></translation>
+        <translation>Предупреждение о размере</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="151"/>
+        <location filename="../src/mainwindow.cpp" line="783"/>
         <source>The target device %1 is larger than %2 GB.
 
 This may indicate you have selected the wrong device.
 Are you sure you want to proceed?</source>
-        <translation type="unfinished"></translation>
+        <translation>Целевое устройство %1 превышает размер %2 ГБ.
+
+Это может означать, что вы выбрали неверное устройство.
+Уверены, что хотите продолжить?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="158"/>
+        <location filename="../src/mainwindow.cpp" line="790"/>
         <source>Large Target Device Warning</source>
-        <translation type="unfinished"></translation>
+        <translation>Предупреждение о большом целевом устройстве</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="248"/>
+        <location filename="../src/mainwindow.cpp" line="194"/>
         <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
 
 Please wait until the process is completed</source>
@@ -334,37 +382,37 @@ Please wait until the process is completed</source>
 Пожалуйста, дождитесь завершения операции</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="260"/>
+        <location filename="../src/mainwindow.cpp" line="205"/>
         <source>MX Live Usb Maker</source>
         <translation>MX Live USB Maker</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
         <source>Success</source>
         <translation>Успешно</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
         <source>LiveUSB creation successful!</source>
         <translation>Создание LiveUSB завершено успешно!</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="439"/>
+        <location filename="../src/mainwindow.cpp" line="398"/>
         <source>Error encountered in the LiveUSB creation process</source>
         <translation>Произошла ошибка при создании LiveUSB</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="497"/>
+        <location filename="../src/mainwindow.cpp" line="464"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="497"/>
+        <location filename="../src/mainwindow.cpp" line="464"/>
         <source>Please select a USB device to write to</source>
         <translation>Выберите USB накопитель для записи</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="500"/>
+        <location filename="../src/mainwindow.cpp" line="467"/>
         <source>These actions will destroy all data on 
 
 </source>
@@ -373,85 +421,85 @@ Please wait until the process is completed</source>
 </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="501"/>
+        <location filename="../src/mainwindow.cpp" line="468"/>
         <source>Do you wish to continue?</source>
         <translation>Вы хотите продолжить?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="533"/>
+        <location filename="../src/mainwindow.cpp" line="500"/>
         <source>About %1</source>
         <translation>О %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="534"/>
+        <location filename="../src/mainwindow.cpp" line="501"/>
         <source>Version: </source>
         <translation>Версия: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../src/mainwindow.cpp" line="503"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Приложение для создания live-usb из файла ISO, другого live-usb, live-cd/dvd или запущенной live системы.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="539"/>
+        <location filename="../src/mainwindow.cpp" line="506"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="540"/>
+        <location filename="../src/mainwindow.cpp" line="507"/>
         <source>%1 License</source>
         <translation>%1 Лицензия</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="547"/>
+        <location filename="../src/mainwindow.cpp" line="514"/>
         <source>%1 Help</source>
         <translation>%1 Справка</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="555"/>
+        <location filename="../src/mainwindow.cpp" line="522"/>
         <source>Select an ISO file to write to the USB drive</source>
         <translation>Выберите файл ISO для записи на USB накопитель</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="556"/>
+        <location filename="../src/mainwindow.cpp" line="523"/>
         <source>ISO Files (*.iso);;All Files (*.*)</source>
         <translation>Файлы вида ISO (*.iso);;Файлы всех типов (*.*)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="561"/>
-        <location filename="../mainwindow.cpp" line="611"/>
+        <location filename="../src/mainwindow.cpp" line="528"/>
+        <location filename="../src/mainwindow.cpp" line="578"/>
         <source>Select Source Directory</source>
         <translation>Выберите директорию источника</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="570"/>
+        <location filename="../src/mainwindow.cpp" line="537"/>
         <source>Could not find linuxfs file</source>
         <translation>Не удалось найти файл linuxfs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="585"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
         <source>Hide advanced options</source>
         <translation>Скрыть расширенные опции</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="610"/>
-        <location filename="../mainwindow.cpp" line="629"/>
+        <location filename="../src/mainwindow.cpp" line="577"/>
+        <location filename="../src/mainwindow.cpp" line="596"/>
         <source>Select Source</source>
         <translation>Выберите источник</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="615"/>
-        <location filename="../mainwindow.cpp" line="637"/>
+        <location filename="../src/mainwindow.cpp" line="582"/>
+        <location filename="../src/mainwindow.cpp" line="604"/>
         <source>Select ISO file</source>
         <translation>Выберите файл ISO</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="631"/>
+        <location filename="../src/mainwindow.cpp" line="598"/>
         <source>clone</source>
         <translation>клонировать</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="698"/>
+        <location filename="../src/mainwindow.cpp" line="665"/>
         <source>Could not find a log file at: </source>
         <translation>Не удалось найти файл журнала в:</translation>
     </message>
@@ -459,64 +507,64 @@ Please wait until the process is completed</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="74"/>
+        <location filename="../src/about.cpp" line="74"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="75"/>
-        <location filename="../about.cpp" line="85"/>
+        <location filename="../src/about.cpp" line="75"/>
+        <location filename="../src/about.cpp" line="85"/>
         <source>Changelog</source>
         <translation>Список изменений</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="76"/>
+        <location filename="../src/about.cpp" line="76"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="99"/>
+        <location filename="../src/about.cpp" line="99"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрыть</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../src/main.cpp" line="60"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Приложение для создания live-usb из файла ISO, другого live-usb, live-cd/dvd или запущенной live системы.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../src/main.cpp" line="64"/>
         <source>filename</source>
         <translation>имя файла</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../src/main.cpp" line="64"/>
         <source>Name of .iso file to open</source>
         <translation>Имя файла .iso для открытия</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../src/main.cpp" line="65"/>
         <source>[filename]</source>
         <translation>[имя файла]</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../src/main.cpp" line="93"/>
+        <location filename="../src/main.cpp" line="102"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="88"/>
+        <location filename="../src/main.cpp" line="94"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="96"/>
+        <location filename="../src/main.cpp" line="102"/>
         <source>You must run this program as root.</source>
         <translation>Вы должны запустить программу от имени суперпользователя.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="111"/>
+        <location filename="../src/main.cpp" line="117"/>
         <source>version:</source>
         <translation>версия:</translation>
     </message>
